package com.ruoyi.inventory.mapper;

import java.util.List;
import com.ruoyi.inventory.domain.HealthcareInventoryStoreroom;

/**
 * 库房管理Mapper接口
 * 
 * @author ruoyi
 * @date 2024-10-28
 */
public interface HealthcareInventoryStoreroomMapper 
{
    /**
     * 查询库房管理
     * 
     * @param id 库房管理主键
     * @return 库房管理
     */
    public HealthcareInventoryStoreroom selectHealthcareInventoryStoreroomById(Long id);

    /**
     * 查询库房管理列表
     * 
     * @param healthcareInventoryStoreroom 库房管理
     * @return 库房管理集合
     */
    public List<HealthcareInventoryStoreroom> selectHealthcareInventoryStoreroomList(HealthcareInventoryStoreroom healthcareInventoryStoreroom);

    /**
     * 新增库房管理
     * 
     * @param healthcareInventoryStoreroom 库房管理
     * @return 结果
     */
    public int insertHealthcareInventoryStoreroom(HealthcareInventoryStoreroom healthcareInventoryStoreroom);

    /**
     * 修改库房管理
     * 
     * @param healthcareInventoryStoreroom 库房管理
     * @return 结果
     */
    public int updateHealthcareInventoryStoreroom(HealthcareInventoryStoreroom healthcareInventoryStoreroom);

    /**
     * 删除库房管理
     * 
     * @param id 库房管理主键
     * @return 结果
     */
    public int deleteHealthcareInventoryStoreroomById(Long id);

    /**
     * 批量删除库房管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHealthcareInventoryStoreroomByIds(Long[] ids);

    public List<HealthcareInventoryStoreroom> selectHealthcareInventoryStoreroomExcel(HealthcareInventoryStoreroom healthcareInventoryStoreroom);

    HealthcareInventoryStoreroom selectHealthcareInventoryStoreroomByName(String storeroomName);
}
