package com.ruoyi.inventory.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.inventory.domain.HealthcareInventoryStoreroom;
import com.ruoyi.inventory.service.IHealthcareInventoryStoreroomService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 库房管理Controller
 * 
 * @author ruoyi
 * @date 2024-10-28
 */
@RestController
@RequestMapping("/pasd-healthcare/storeroom")
public class HealthcareInventoryStoreroomController extends BaseController
{
    @Autowired
    private IHealthcareInventoryStoreroomService healthcareInventoryStoreroomService;

    /**
     * 查询库房管理列表
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:storeroom:list')")
    @GetMapping("/list")
    public TableDataInfo list(HealthcareInventoryStoreroom healthcareInventoryStoreroom)
    {
        startPage();
        List<HealthcareInventoryStoreroom> list = healthcareInventoryStoreroomService.selectHealthcareInventoryStoreroomList(healthcareInventoryStoreroom);
        return getDataTable(list);
    }

    /**
     * 导出库房管理列表
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:storeroom:export')")
    @Log(title = "库房管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthcareInventoryStoreroom healthcareInventoryStoreroom)
    {
        List<HealthcareInventoryStoreroom> list = healthcareInventoryStoreroomService.selectHealthcareInventoryStoreroomList(healthcareInventoryStoreroom);
        ExcelUtil<HealthcareInventoryStoreroom> util = new ExcelUtil<HealthcareInventoryStoreroom>(HealthcareInventoryStoreroom.class);
        util.exportExcel(response, list, "库房管理数据");
    }

    /**
     * 获取库房管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:storeroom:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(healthcareInventoryStoreroomService.selectHealthcareInventoryStoreroomById(id));
    }

    /**
     * 新增库房管理
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:storeroom:add')")
    @Log(title = "库房管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HealthcareInventoryStoreroom healthcareInventoryStoreroom)
    {
        return toAjax(healthcareInventoryStoreroomService.insertHealthcareInventoryStoreroom(healthcareInventoryStoreroom));
    }

    /**
     * 修改库房管理
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:storeroom:edit')")
    @Log(title = "库房管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HealthcareInventoryStoreroom healthcareInventoryStoreroom)
    {
        return toAjax(healthcareInventoryStoreroomService.updateHealthcareInventoryStoreroom(healthcareInventoryStoreroom));
    }

    /**
     * 删除库房管理
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:storeroom:remove')")
    @Log(title = "库房管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(healthcareInventoryStoreroomService.deleteHealthcareInventoryStoreroomByIds(ids));
    }
}
